@@ -1,6 +1,7 @@
 import simplejson
 
 from django.contrib.auth.models import User
+from django.core.exceptions import ValidationError
 from django.db import models
 from django.utils.translation import ugettext as _
 
@@ -20,6 +21,17 @@ class Tag(models.Model):
         return self.name
 
 
+def validate_job_json(data):
+    try:
+        ob = simplejson.loads(data)
+    except ValueError, e:
+        raise ValidationError(str(e))
+    else:
+        if not isinstance(ob, dict):
+            raise ValidationError(
+                "job json must be an object, not %s" % type(ob).__name__)
+
+
 class DeviceType(models.Model):
     """
     A class of device, for example a pandaboard or a snowball.
@@ -30,7 +42,8 @@ class DeviceType(models.Model):
     def __unicode__(self):
         return self.name
 
-    # We will probably hang uboot command and such off here...
+    health_check_job = models.TextField(
+        null=True, blank=True, default=None, validators=[validate_job_json])
 
 
 class Device(models.Model):
@@ -50,6 +63,14 @@ class Device(models.Model):
         (OFFLINING, 'Going offline'),
     )
 
+    # A device health shows a device is ready to test or not
+    HEALTH_UNKNOWN, HEALTH_PASS, HEALTH_FAIL = range(3)
+    HEALTH_CHOICES = (
+        (HEALTH_UNKNOWN, 'Unknown'),
+        (HEALTH_PASS, 'Pass'),
+        (HEALTH_FAIL, 'Fail'),
+    )
+
     hostname = models.CharField(
         verbose_name = _(u"Hostname"),
         max_length = 200,
@@ -60,7 +81,7 @@ class Device(models.Model):
         DeviceType, verbose_name=_(u"Device type"))
 
     current_job = models.ForeignKey(
-        "TestJob", blank=True, unique=True, null=True)
+        "TestJob", blank=True, unique=True, null=True, related_name='+')
 
     tags = models.ManyToManyField(Tag, blank=True)
 
@@ -70,6 +91,15 @@ class Device(models.Model):
         verbose_name = _(u"Device status"),
     )
 
+    health_status = models.IntegerField(
+        choices = HEALTH_CHOICES,
+        default = HEALTH_UNKNOWN,
+        verbose_name = _(u"Device Health"),
+    )
+
+    last_health_report_job = models.ForeignKey(
+            "TestJob", blank=True, unique=True, null=True, related_name='+')
+
     def __unicode__(self):
         return self.hostname
 
@@ -77,6 +107,10 @@ class Device(models.Model):
     def get_absolute_url(self):
         return ("lava.scheduler.device.detail", [self.pk])
 
+    @models.permalink
+    def get_device_health_url(self):
+        return ("lava.scheduler.labhealth.detail", [self.pk])
+
     def recent_jobs(self):
         return TestJob.objects.select_related(
             "actual_device",
@@ -111,6 +145,7 @@ class Device(models.Model):
             created_by=user, device=self, old_state=self.status,
             new_state=new_status, message=reason, job=None).save()
         self.status = new_status
+        self.health_status = Device.HEALTH_UNKNOWN
         self.save()
 
     #@classmethod
@@ -156,6 +191,8 @@ class TestJob(models.Model):
         default = None
     )
 
+    health_check = models.BooleanField(default=False)
+
     # Only one of these two should be non-null.
     requested_device = models.ForeignKey(
         Device, null=True, default=None, related_name='+', blank=True)
@@ -229,6 +266,9 @@ class TestJob(models.Model):
             raise JSONDataError(
                 "Neither 'target' nor 'device_type' found in job data.")
         job_name = job_data.get('job_name', '')
+
+        is_check = job_data.get('health_check', False)
+
         tags = []
         for tag_name in job_data.get('device_tags', []):
             try:
@@ -237,7 +277,8 @@ class TestJob(models.Model):
                 raise JSONDataError("tag %r does not exist" % tag_name)
         job = TestJob(
             definition=json_data, submitter=user, requested_device=target,
-            requested_device_type=device_type, description=job_name)
+            requested_device_type=device_type, description=job_name,
+            health_check=is_check)
         job.save()
         for tag in tags:
             job.tags.add(tag)
