@@ -6,6 +6,12 @@ urlpatterns = patterns(
     url(r'^$', 
         'index',
         name='lava.scheduler'),
+    url(r'^active_jobs_json$', 
+        'index_active_jobs_json',
+        name='lava.scheduler'),
+    url(r'^devices_json$', 
+        'index_devices_json',
+        name='lava.scheduler'),
     url(r'^alljobs$', 
         'job_list', 
         name='lava.scheduler.job.list'),
@@ -15,12 +21,30 @@ urlpatterns = patterns(
     url(r'^device/(?P<pk>[-_a-zA-Z0-9]+)$', 
         'device_detail', 
         name='lava.scheduler.device.detail'),
+    url(r'^device/(?P<pk>[-_a-zA-Z0-9]+)/recent_jobs_json$', 
+        'recent_jobs_json', 
+        name='lava.scheduler.device.recent_jobs_json'),
+    url(r'^device/(?P<pk>[-_a-zA-Z0-9]+)/transition_json$', 
+        'transition_json', 
+        name='lava.scheduler.device.transition_json'),
     url(r'^device/(?P<pk>[-_a-zA-Z0-9]+)/maintenance$', 
         'device_maintenance_mode', 
         name='lava.scheduler.device.maintenance'),
     url(r'^device/(?P<pk>[-_a-zA-Z0-9]+)/online$',
         'device_online',
         name='lava.scheduler.device.online'),
+    url(r'^labhealth/$',
+        'lab_health',
+        name='lava.scheduler.labhealth'),
+    url(r'^labhealth/health_json$',
+        'lab_health_json',
+        name='lava.scheduler.labhealth_json'),
+    url(r'^labhealth/device/(?P<pk>[-_a-zA-Z0-9]+)$',
+        'health_job_list',
+        name='lava.scheduler.labhealth.detail'),
+    url(r'^labhealth/device/(?P<pk>[-_a-zA-Z0-9]+)/job_json$',
+        'health_jobs_json',
+        name='lava.scheduler.labhealth.health_jobs_json'),
     url(r'^job/(?P<pk>[0-9]+)$',
         'job_detail',
         name='lava.scheduler.job.detail'),
